==> haskell-crypto-token-0.1.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-token.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-token
version:              0.1.1
visibility:           public
id:                   crypto-token-0.1.1-KNSIbhZGaYsFS31FgtJMVg
key:                  crypto-token-0.1.1-KNSIbhZGaYsFS31FgtJMVg
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             crypto tokens
description:          Encrypted tokens/tickets to keep state in the client side.
category:             Cryptography, Network
abi:                  90049dda084a44e3915b552a97a2f789
exposed:              True
exposed-modules:      Crypto.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-token-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-token-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-token-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-token
hs-libraries:         HScrypto-token-0.1.1-KNSIbhZGaYsFS31FgtJMVg
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    crypton-1.0.2-7o8Jrkh7igGF3aYIPFY8Rt
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM

haddock-interfaces:
    /usr/share/doc/haskell-crypto-token/html/crypto-token.haddock

haddock-html:         /usr/share/doc/haskell-crypto-token/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-token-0.1.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-token.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-token
version:              0.1.1
visibility:           public
id:                   crypto-token-0.1.1-HgiSpaePWyzHUPyTCSJPFw
key:                  crypto-token-0.1.1-HgiSpaePWyzHUPyTCSJPFw
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             crypto tokens
description:          Encrypted tokens/tickets to keep state in the client side.
category:             Cryptography, Network
abi:                  b65088a75279b5110799577c73c3a9e8
exposed:              True
exposed-modules:      Crypto.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-token-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-token-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-token-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-token
hs-libraries:         HScrypto-token-0.1.1-HgiSpaePWyzHUPyTCSJPFw
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    crypton-1.0.2-BgHjNZ2cORQ1QFrdVzHSiv
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM

haddock-interfaces:
    /usr/share/doc/haskell-crypto-token/html/crypto-token.haddock

haddock-html:         /usr/share/doc/haskell-crypto-token/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
